jscep 2.5.5 API

This document is the API specification for the jscep SCEP library.

For more information about the jscep project, please visit the project web site at jscep.org, where you will find the latest documentation, source code and examples.

Packages
Package
Description
Provides classes and interfaces to represent ASN.1 objects specific to SCEP.
Provides classes to represent a SCEP client.
 
Provides an interface and several implementation classes for verifying the identity of a certificate.
Provides classes and interfaces to represent SCEP Secure Message Objects.
Provides classes to represent a SCEP server.
Provides classes and interfaces to manipulate SCEP transactions.
Provides classes for providing HTTP transport to SCEP messages.
Provides classes and interfaces to represent SCEP requests.
Provides classes and interfaces to handle and represent SCEP responses.
Provides classes for performing miscellaneous functions.